@@ -306,7 +306,7 @@ def _merge_type(t0, t1, name, cls):
   # t1 is a base of t0
   if t1 in t0.mro:
     return t0
-  raise GenericTypeError(cls, "Conflicting value for TypeVar %s" % name)
+  raise GenericTypeError(cls, f"Conflicting value for TypeVar {name}")
 
 
 def parse_formal_type_parameters(
@@ -845,3 +845,24 @@ def update_args_dict(args: ArgsDict, update: ArgsDict, node: cfg.CFGNode):
       args[k].PasteVariable(v, node)
     else:
       args[k] = v
+
+
+def show_constant(val: _BaseValue) -> str:
+  """Pretty-print a value if it is a constant.
+
+  Recurses into a constant, printing the underlying Python value for constants
+  and just using "..." for everything else (e.g., Variables). This is useful for
+  generating clear error messages that show the exact values related to an error
+  while preventing implementation details from leaking into the message.
+
+  Args:
+    val: an abstract value.
+
+  Returns:
+    A string of the pretty-printed constant.
+  """
+  def _ellipsis_printer(v):
+    if _isinstance(v, "PythonConstant"):
+      return v.str_of_constant(_ellipsis_printer)
+    return "..."
+  return _ellipsis_printer(val)
