@@ -144,7 +144,7 @@ class Converter(utils.ContextWeakrefMixin):
     if constant_type is None:
       return "constant"
     elif isinstance(constant_type, tuple):
-      return "(%s)" % ", ".join(self.constant_name(c) for c in constant_type)
+      return f"({', '.join(self.constant_name(c) for c in constant_type)})"
     else:
       return constant_type.__name__
 
@@ -169,7 +169,7 @@ class Converter(utils.ContextWeakrefMixin):
         isinstance(val.pyval, constant_type or object)):
       return val.pyval
     name = self.constant_name(constant_type)
-    raise abstract_utils.ConversionError("%s is not of type %s" % (val, name))
+    raise abstract_utils.ConversionError(f"{val} is not of type {name}")
 
   def name_to_value(self, name, subst=None, ast=None):
     if ast is None:
@@ -197,7 +197,7 @@ class Converter(utils.ContextWeakrefMixin):
     elif value is False:
       return self.false.to_variable(node)
     else:
-      raise ValueError("Invalid bool value: %r" % value)
+      raise ValueError(f"Invalid bool value: {value!r}")
 
   def build_int(self, node):
     i = self.primitive_class_instances[int]
@@ -453,7 +453,7 @@ class Converter(utils.ContextWeakrefMixin):
                                                     discard_concrete_values)
                                for i, v in enumerate(pyval)))
     raise ValueError(
-        "Cannot convert {} to an abstract value".format(pyval.__class__))
+        f"Cannot convert {pyval.__class__} to an abstract value")
 
   def constant_to_value(self, pyval, subst=None, node=None):
     """Like constant_to_var, but convert to an abstract.BaseValue.
@@ -598,6 +598,25 @@ class Converter(utils.ContextWeakrefMixin):
       value = pyval
     return self.constant_to_value(value, subst, self.ctx.root_node)
 
+  def _special_constant_to_value(self, name):
+    """Special-case construction of some pytd values."""
+    if name == "builtins.super":
+      return self.ctx.special_builtins["super"]
+    elif name == "builtins.object":
+      return self.object_type
+    elif name == "types.ModuleType":
+      return self.module_type
+    elif name == "_importlib_modulespec.ModuleType":
+      # Python 3's typeshed uses a stub file indirection to define ModuleType
+      # even though it is exported via types.pyi.
+      return self.module_type
+    elif name == "types.FunctionType":
+      return self.function_type
+    elif name == "types.NoneType":
+      return self.none_type
+    else:
+      return None
+
   def _constant_to_value(self, pyval, subst, get_node):
     """Create a BaseValue that represents a python constant.
 
@@ -657,18 +676,9 @@ class Converter(utils.ContextWeakrefMixin):
       mod = self.ctx.loader.import_name(pyval.module_name)
       return self._create_module(mod)
     elif isinstance(pyval, pytd.Class):
-      if pyval.name == "builtins.super":
-        return self.ctx.special_builtins["super"]
-      elif pyval.name == "builtins.object":
-        return self.object_type
-      elif pyval.name == "types.ModuleType":
-        return self.module_type
-      elif pyval.name == "_importlib_modulespec.ModuleType":
-        # Python 3's typeshed uses a stub file indirection to define ModuleType
-        # even though it is exported via types.pyi.
-        return self.module_type
-      elif pyval.name == "types.FunctionType":
-        return self.function_type
+      val = self._special_constant_to_value(pyval.name)
+      if val:
+        return val
       else:
         module, dot, base_name = pyval.name.rpartition(".")
         # typing.TypingContainer intentionally loads the underlying pytd types.
@@ -906,5 +916,5 @@ class Converter(utils.ContextWeakrefMixin):
           for i, item in enumerate(pyval)
       ])
     else:
-      raise NotImplementedError("Can't convert constant %s %r" %
-                                (type(pyval), pyval))
+      raise NotImplementedError("Can't convert constant "
+                                f"{type(pyval)} {pyval!r}")
