@@ -1,15 +1,13 @@
 """Tests for convert.py."""
 
 from pytype import config
-from pytype import context
-from pytype import errors
 from pytype import file_utils
-from pytype import load_pytd
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.tests import test_base
+from pytype.tests import test_utils
 
 import unittest
 
@@ -19,8 +17,7 @@ class ConvertTest(test_base.UnitTest):
   def setUp(self):
     super().setUp()
     options = config.Options.create(python_version=self.python_version)
-    self._ctx = context.Context(errors.ErrorLog(), options,
-                                load_pytd.Loader(options))
+    self._ctx = test_utils.make_context(options)
 
   def _load_ast(self, name, src):
     with file_utils.Tempdir() as d:
