@@ -119,7 +119,7 @@ class ErrorTest(unittest.TestCase):
     with file_utils.Tempdir() as d:
       filename = d.create_file("errors.csv")
       errorlog.print_to_csv_file(filename)
-      with open(filename, "r") as fi:
+      with open(filename) as fi:
         rows = list(csv.reader(fi, delimiter=","))
         self.assertEqual(len(rows), 2)
         for i, row in enumerate(rows):
@@ -138,7 +138,7 @@ class ErrorTest(unittest.TestCase):
     with file_utils.Tempdir() as d:
       filename = d.create_file("errors.csv")
       errorlog.print_to_csv_file(filename)
-      with open(filename, "r") as fi:
+      with open(filename) as fi:
         (_, _, _, _, actual_details), = list(csv.reader(fi, delimiter=","))
         self.assertMultiLineEqual(actual_details, textwrap.dedent("""
           some
@@ -163,7 +163,7 @@ class ErrorLogBaseTest(unittest.TestCase):
   def test_error(self):
     errorlog = errors.ErrorLog()
     op = test_utils.FakeOpcode("foo.py", 123, "foo")
-    errorlog.error(op.to_stack(), "unknown attribute %s" % "xyz")
+    errorlog.error(op.to_stack(), f"unknown attribute {'xyz'}")
     self.assertEqual(len(errorlog), 1)
     e = list(errorlog)[0]  # iterate the log and save the first error.
     self.assertEqual(errors.SEVERITY_ERROR, e._severity)
@@ -266,7 +266,7 @@ class ErrorLogBaseTest(unittest.TestCase):
   def test_color_print_to_stderr(self):
     errorlog = errors.ErrorLog()
     op = test_utils.FakeOpcode("foo.py", 123, "foo")
-    errorlog.error(op.to_stack(), "unknown attribute %s" % "xyz")
+    errorlog.error(op.to_stack(), f"unknown attribute {'xyz'}")
     self.assertEqual(len(errorlog), 1)
 
     mock_stderr = io.StringIO()
@@ -279,7 +279,7 @@ class ErrorLogBaseTest(unittest.TestCase):
   def test_color_print_to_file(self):
     errorlog = errors.ErrorLog()
     op = test_utils.FakeOpcode("foo.py", 123, "foo")
-    errorlog.error(op.to_stack(), "unknown attribute %s" % "xyz")
+    errorlog.error(op.to_stack(), f"unknown attribute {'xyz'}")
     self.assertEqual(len(errorlog), 1)
 
     string_io = io.StringIO()
@@ -294,7 +294,7 @@ class ErrorDocTest(unittest.TestCase):
                                  "../docs/errors.md")
 
   def _check_and_get_documented_errors(self):
-    with open(self.ERROR_FILE_PATH, "r") as f:
+    with open(self.ERROR_FILE_PATH) as f:
       lines = f.readlines()
     entries = [line[3:].strip() for line in lines if line.startswith("##")]
     counts = collections.Counter(entries)
