@@ -237,8 +237,7 @@ class Base:
 
     def leaves(self):
         for child in self.children:
-            for x in child.leaves():
-                yield x
+            yield from child.leaves()
 
     def depth(self):
         if self.parent is None:
@@ -252,7 +251,7 @@ class Base:
         """
         next_sib = self.next_sibling
         if next_sib is None:
-            return u""
+            return ""
         return next_sib.prefix
 
     if sys.version_info < (3, 0):
@@ -337,8 +336,7 @@ class Node(Base):
 
     def __repr__(self):
         """Return a canonical string representation."""
-        return "%s(%s, %r)" % (self.__class__.__name__,
-                               self.type_repr, self.children)
+        return f"{self.__class__.__name__}({self.type_repr}, {self.children!r})"
 
     def __unicode__(self):
         """
@@ -346,10 +344,9 @@ class Node(Base):
 
         This reproduces the input source exactly.
         """
-        return u"".join(map(str, self.children))
+        return "".join(map(str, self.children))
 
-    if sys.version_info > (3, 0):
-        __str__ = __unicode__
+    __str__ = __unicode__
 
     def _eq(self, other):
         """Compare two nodes for equality (using type, children) -
@@ -370,16 +367,14 @@ class Node(Base):
     def post_order(self):
         """Post-order iterator for the tree."""
         for child in self.children:
-            for node in child.post_order():
-                yield node
+            yield from child.post_order()
         yield self
 
     def pre_order(self):
         """Pre-order iterator for the tree."""
         yield self
         for child in self.children:
-            for node in child.pre_order():
-                yield node
+            yield from child.pre_order()
 
     def _prefix_getter(self):
         """
@@ -465,8 +460,7 @@ class Leaf(Base):
 
     def __repr__(self):
         """Return a canonical string representation."""
-        return "%s(%s, %r)" % (self.__class__.__name__,
-                               self.type_repr, self.value)
+        return f"{self.__class__.__name__}({self.type_repr}, {self.value!r})"
 
     def __unicode__(self):
         """
@@ -476,8 +470,7 @@ class Leaf(Base):
         """
         return self.prefix + str(self.value)
 
-    if sys.version_info > (3, 0):
-        __str__ = __unicode__
+    __str__ = __unicode__
 
     def _eq(self, other):
         """Compare two nodes for equality (type and value)."""
@@ -568,7 +561,7 @@ class BasePattern:
         args = [self.type_repr, self.content, self.name]
         while args and args[-1] is None:
             del args[-1]
-        return "%s(%s)" % (self.__class__.__name__, ", ".join(map(repr, args)))
+        return f"{self.__class__.__name__}({', '.join(map(repr, args))})"
 
     @property
     def type_repr(self):
