@@ -13,18 +13,16 @@ def format_loc(location):
 
 
 def format_def_with_location(defn, loc):
-  return ("%s  | %s %s" % (
-      format_loc(loc), defn.typ.ljust(15), defn.format()))
+  return f"{format_loc(loc)}  | {defn.typ.ljust(15)} {defn.format()}"
 
 
 def format_ref(ref):
-  return ("%s  | %s  %s.%s" % (
-      format_loc(ref.location), ref.typ.ljust(15), ref.scope, ref.name))
+  return (f"{format_loc(ref.location)}  | {ref.typ.ljust(15)}  "
+          f"{ref.scope}.{ref.name}")
 
 
 def format_call(call):
-  return ("%s  | %s  %s" % (
-      format_loc(call.location), "Call".ljust(15), call.func))
+  return f"{format_loc(call.location)}  | {'Call'.ljust(15)}  {call.func}"
 
 
 def typename(node):
@@ -89,7 +87,7 @@ def show_types(index):
     if (category in ("FunctionDef", "IsInstance") or
         typ in ("builtins.module", "__future__._Feature")):
       continue
-    print("%s  |  %s  %s" % (format_loc(location), name.ljust(35), typ))
+    print(f"{format_loc(location)}  |  {name.ljust(35)}  {typ}")
 
 
 def show_index(index):
