@@ -114,8 +114,7 @@ class PytypeValue:
     self.id = self.module + "." + self.name
 
   def format(self):
-    return "%s { %s.%s : %s }" % (
-        self.id, self.module, self.typ, self.name)
+    return f"{self.id} {{ {self.module}.{self.typ} : {self.name} }}"
 
   @classmethod
   def _from_data(cls, data):
@@ -470,7 +469,7 @@ class ScopedVisitor(ast_visitor.BaseVisitor):
     elif c == self._ast.Module:
       return self.module_name
     else:
-      raise Exception("Unexpected scope: %r" % node)
+      raise Exception(f"Unexpected scope: {node!r}")
 
   def iprint(self, x):
     """Print messages indented by scope level, for debugging."""
@@ -557,11 +556,11 @@ class IndexVisitor(ScopedVisitor, traces.MatchAstVisitor):
       # between the start of the AST node and the start of the body. Handles the
       # offset for decorated functions/classes.
       body_start = node.body[0].lineno
-      text = "class %s" % args["name"]
+      text = f"class {args['name']}"
       loc = self.source.find_first_text(node.lineno, body_start, text)
     elif isinstance(node, self._ast.FunctionDef):
       body_start = node.body[0].lineno
-      text = "def %s" % args["name"]
+      text = f"def {args['name']}"
       loc = self.source.find_first_text(node.lineno, body_start, text)
 
     if loc is None:
@@ -1232,7 +1231,7 @@ class VmTrace(source.AbstractTrace):
     types_repr = tuple(
         t and [node_utils.typename(x) for x in t]
         for t in self.types)
-    return "%s %s" % (super().__repr__(), types_repr)
+    return f"{super().__repr__()} {types_repr}"
 
 
 def process_file(options, source_text=None, generate_callgraphs=False,
